"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const SsdpDescriptor_1 = require("./SsdpDescriptor");
const SsdpServiceDescriptor_1 = require("./SsdpServiceDescriptor");
const SsdpType_1 = require("./SsdpType");
class SsdpDeviceDescriptor extends SsdpDescriptor_1.SsdpDescriptor {
    constructor(name) {
        super(name);
        this.services = [];
        this.type = SsdpType_1.SsdpType.device;
    }
    addService(service) {
        let newService;
        if (typeof service === 'string') {
            newService = new SsdpServiceDescriptor_1.SsdpServiceDescriptor(service);
            newService.domain = this.domain;
            newService.type = SsdpType_1.SsdpType.service;
        }
        else {
            newService = service;
        }
        newService.uuid = this.uuid;
        if (newService.domain === undefined) {
            newService.domain = this.domain;
        }
        if (newService.location === undefined) {
            newService.location = this.location;
        }
        this.services.push(newService);
    }
    // uuid:device-UUID::urn:domain-name:device:deviceType:ver
    getUSN(index) {
        switch (index) {
            case 1:
                return `uuid:${this.uuid}`;
            case 2:
                return `uuid:${this.uuid}::urn:${this.domain}:device:${this.name}`;
        }
    }
    getNT(index) {
        switch (index) {
            case 1:
                return `uuid:${this.uuid}`;
            case 2:
                // urn:domain-name:device:deviceType:ver
                return `urn:${this.domain}:device:${this.name}`;
        }
    }
}
exports.SsdpDeviceDescriptor = SsdpDeviceDescriptor;

//# sourceMappingURL=SsdpDeviceDescriptor.js.map
