"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const SsdpType_1 = require("../Descriptors/SsdpType");
const SsdpConstants_1 = require("../SsdpConstants");
const tools_1 = require("../tools");
class MessageFactory {
    constructor(config) {
        this.config = config;
    }
    createAliveMessage(ssdpDescriptor) {
        let messageNumbers = 0;
        const result = []; // new DiscoveryMessage();
        const base = [];
        const cacheControlSec = this.config.SsdpAdvertiser.cacheControl;
        base.push(SsdpConstants_1.SsdpConstants.StartLine.NOTIFY);
        base.push(`NTS: ${SsdpConstants_1.SsdpConstants.ssdpAlive}`);
        base.push(`HOST: ${SsdpConstants_1.SsdpConstants.ipv4Address}`);
        base.push(`CACHE-CONTROL: max-age=${cacheControlSec}`);
        base.push(`SERVER: ${tools_1.getOsAndVersion()} UPnP/1.1 ${this.config.ProductName}/${this.config.ProductVersion}`);
        // SERVER: unix/5.1 MyProduct/1.0
        switch (ssdpDescriptor.type) {
            case SsdpType_1.SsdpType.rootDevice:
                messageNumbers = 3;
                break;
            case SsdpType_1.SsdpType.device:
                messageNumbers = 2;
                break;
            case SsdpType_1.SsdpType.service:
                messageNumbers = 1;
                break;
        }
        for (let index = 1; index <= (messageNumbers); index += 1) {
            const copy = base.slice();
            copy.push(`NT: ${ssdpDescriptor.getNT(index)}`);
            copy.push(`USN: ${ssdpDescriptor.getUSN(index)}`);
            copy.push(`LOCATION: ${ssdpDescriptor.location}`);
            ssdpDescriptor.header.forEach(h => copy.push(`${h.key}: ${h.value}`));
            copy.push('');
            result.push(copy.join('\r\n'));
        }
        return result;
    }
    createByebyeMessage(ssdpDescriptor) {
        let messageNumbers = 0;
        const result = []; // new DiscoveryMessage();
        const base = [];
        base.push(SsdpConstants_1.SsdpConstants.StartLine.NOTIFY);
        base.push(`NTS: ${SsdpConstants_1.SsdpConstants.ssdpByebye}`);
        base.push(`HOST: ${SsdpConstants_1.SsdpConstants.ipv4Address}`);
        switch (ssdpDescriptor.type) {
            case SsdpType_1.SsdpType.rootDevice:
                messageNumbers = 3;
                break;
            case SsdpType_1.SsdpType.device:
                messageNumbers = 2;
                break;
            case SsdpType_1.SsdpType.service:
                messageNumbers = 1;
                break;
        }
        for (let index = 1; index <= (messageNumbers); index += 1) {
            const copy = base.slice();
            copy.push(`NT: ${ssdpDescriptor.getNT(index)}`);
            copy.push(`USN: ${ssdpDescriptor.getUSN(index)}`);
            copy.push('');
            result.push(copy.join('\r\n'));
        }
        return result;
    }
}
exports.MessageFactory = MessageFactory;

//# sourceMappingURL=MessageFactory.js.map
